# Virgil

[![PyPI version](https://badge.fury.io/py/virgil.svg)](https://badge.fury.io/py/virgil)
[![License](https://img.shields.io/badge/License-MIT-blue.svg)](https://github.com/QuicksilverMachine/virgil/blob/master/LICENSE)

Virgil is a dependency management library
